@@ -34,7 +34,6 @@ Here is a minimal deployable pattern definition:
 const { ApiGatewayToLambda } = require('@aws-solutions-constructs/aws-apigateway-lambda');
 
 new ApiGatewayToLambda(stack, 'ApiGatewayToLambdaPattern', {
-    deployLambda: true,
     lambdaFunctionProps: {
         runtime: lambda.Runtime.NODEJS_10_X,
         handler: 'index.handler',
@@ -60,9 +59,8 @@ new ApiGatewayToLambda(scope: Construct, id: string, props: ApiGatewayToLambdaPr
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the `existingLambdaObj` property.|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|An optional, existing Lambda function. This property is required if `deployLambda` is set to false.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user-provided props to override the default props for the Lambda function. This property is only required if `deployLambda` is set to true.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |apiGatewayProps?|[`api.LambdaRestApiProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.LambdaRestApi.html)|Optional user-provided props to override the default props for the API.|
 
 ## Pattern Properties
@@ -71,6 +69,8 @@ new ApiGatewayToLambda(scope: Construct, id: string, props: ApiGatewayToLambdaPr
 |:-------------|:----------------|-----------------|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
 |restApi|[`api.LambdaRestApi`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.LambdaRestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
+|apiGatewayCloudWatchRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
+|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
 
 ## Default settings
 
@@ -110,7 +110,9 @@ import publication
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
+import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
+import aws_cdk.aws_logs
 import aws_cdk.core
 
 
@@ -129,18 +131,16 @@ class ApiGatewayToLambda(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         api_gateway_props: typing.Any = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Any = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
-        :param existing_lambda_obj: An optional, existing Lambda function. This property is required if ``deployLambda`` is set to false. Default: - None
-        :param lambda_function_props: Optional user-provided props to override the default props for the Lambda function. This property is only required if ``deployLambda`` is set to true. Default: - Default props are used.
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
 
         access:
         :access:: public
@@ -150,7 +150,6 @@ class ApiGatewayToLambda(
         :summary:: Constructs a new instance of the ApiGatewayToLambda class.
         """
         props = ApiGatewayToLambdaProps(
-            deploy_lambda=deploy_lambda,
             api_gateway_props=api_gateway_props,
             existing_lambda_obj=existing_lambda_obj,
             lambda_function_props=lambda_function_props,
@@ -163,6 +162,16 @@ class ApiGatewayToLambda(
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return jsii.get(self, "apiGateway")
 
+    @builtins.property
+    @jsii.member(jsii_name="apiGatewayCloudWatchRole")
+    def api_gateway_cloud_watch_role(self) -> aws_cdk.aws_iam.Role:
+        return jsii.get(self, "apiGatewayCloudWatchRole")
+
+    @builtins.property
+    @jsii.member(jsii_name="apiGatewayLogGroup")
+    def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
+        return jsii.get(self, "apiGatewayLogGroup")
+
     @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
@@ -173,7 +182,6 @@ class ApiGatewayToLambda(
     jsii_type="@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "api_gateway_props": "apiGatewayProps",
         "existing_lambda_obj": "existingLambdaObj",
         "lambda_function_props": "lambdaFunctionProps",
@@ -183,21 +191,21 @@ class ApiGatewayToLambdaProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         api_gateway_props: typing.Any = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Any = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         """The properties for the ApiGatewayToLambda class.
 
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
-        :param existing_lambda_obj: An optional, existing Lambda function. This property is required if ``deployLambda`` is set to false. Default: - None
-        :param lambda_function_props: Optional user-provided props to override the default props for the Lambda function. This property is only required if ``deployLambda`` is set to true. Default: - Default props are used.
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
         """
-        self._values = {
-            "deploy_lambda": deploy_lambda,
-        }
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
+                **lambda_function_props
+            )
+        self._values = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
         if existing_lambda_obj is not None:
@@ -205,17 +213,6 @@ class ApiGatewayToLambdaProps:
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
 
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new Lambda function or use an existing Lambda function.
-
-        If set to false, you must provide an existing function for the ``existingLambdaObj`` property.
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
-
     @builtins.property
     def api_gateway_props(self) -> typing.Any:
         """Optional user-provided props to override the default props for the API.
@@ -227,9 +224,7 @@ class ApiGatewayToLambdaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """An optional, existing Lambda function.
-
-        This property is required if ``deployLambda`` is set to false.
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
@@ -237,10 +232,10 @@ class ApiGatewayToLambdaProps:
         return self._values.get("existing_lambda_obj")
 
     @builtins.property
-    def lambda_function_props(self) -> typing.Any:
-        """Optional user-provided props to override the default props for the Lambda function.
-
-        This property is only required if ``deployLambda`` is set to true.
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used.
